@@ -38,3 +38,5 @@ from piedra import Piedra
 from menu import Menu
 from opcion import Opcion
 from tortuga import Tortuga
+from mapa import Mapa
+from martian import Martian
