@@ -26,9 +26,9 @@ class Nave(Animacion):
         Animacion.actualizar(self)
 
         if pilas.mundo.control.izquierda:
-            self.rotacion += self.velocidad
-        elif pilas.mundo.control.derecha:
             self.rotacion -= self.velocidad
+        elif pilas.mundo.control.derecha:
+            self.rotacion += self.velocidad
 
         if pilas.mundo.control.arriba:
             self.avanzar()
@@ -56,7 +56,7 @@ class Nave(Animacion):
 
     def avanzar(self):
         "Hace avanzar la nave en direccion a su angulo."
-        rotacion_en_radianes = math.radians(self.rotacion + 90)
+        rotacion_en_radianes = math.radians(-self.rotacion + 90)
         dx = math.cos(rotacion_en_radianes) * self.velocidad
         dy = math.sin(rotacion_en_radianes) * self.velocidad
         self.x += dx
