@@ -21,27 +21,11 @@ class Grupo(list):
 
     """
 
-    def __getattribute__(self, attr):
+    def __getattr__(self, attr):
         """Esta funcion se asegura de que cada vez que se invoque a un metodo
         del grupo, en realidad, el grupo va a invocar a ese metodo pero
         en todos sus elementos. Algo asi como un map."""
 
-        def desordenar():
-            for a in self:
-                a.x = random.randint(-300, 300)
-                a.y = random.randint(-200, 200)
-
-        def limpiar():
-            eliminar = list(self)
-            for e in eliminar:
-                e.eliminar()
-
-
-        if attr == 'desordenar':
-            return desordenar
-        elif attr == 'limpiar':
-            return limpiar
-
         def map_a_todos(*k, **kw):
             for a in self:
                 funcion = getattr(a, attr)
@@ -52,3 +36,13 @@ class Grupo(list):
     def __setattr__(self, atributo, valor):
         for a in self:
             setattr(a, atributo, valor)
+
+    def desordenar(self):
+        for a in self:
+            a.x = random.randint(-300, 300)
+            a.y = random.randint(-200, 200)
+
+    def limpiar(self):
+        eliminar = list(self)
+        for e in eliminar:
+            e.eliminar()
